
//
//  This program is free software: you can redistribute it and/or modify
//  it under the terms of the GNU General Public License as published by
//  the Free Software Foundation, either version 3 of the License, or
//  (at your option) any later version.
//
//  This program and source is distributed in the hope that it will be
//  useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//  GNU General Public License for more details.
//
//  You should have received a copy of the GNU General Public License
//  along with this program.  If not, see <http://www.gnu.org/licenses/>.
//

struct PS_INPUT
{
    float4 inPosition : POSITION;
    float2 inTexCoord0 : TEXCOORD0;
    float2 screenpos : VPOS;
};
 
sampler2D leftImage  : register(s0);     // left image
sampler2D rightImage : register(s1);	 // right image
float g_frameCount   : register(c0);     // total count
float g_frameIndex   : register(c1);     // left or right?
float2 g_resolution  : register(c8);     // content resolution   
float4 g_stereop     : register(c9);	 // stereo parameters  
                    
float4 main(PS_INPUT input) : COLOR
{
    float4  output = float4(1,1,1,1);											    
    float2  texcoord = input.inTexCoord0;
    float2  screenpos = input.screenpos;
    float   proscenium = g_stereop.x;
    float2  fsep = float2( g_stereop.y, 0.0f );

    texcoord.x = texcoord.x + 0.5 / g_resolution.x;
    texcoord.y = texcoord.y + 0.5 / g_resolution.y;
   
    float3 leftMask = float3( 0.299, 0.587, 0.114 );
    float3 leftColor = tex2D( leftImage, texcoord - fsep);
    float3 rightColor = tex2D( rightImage, texcoord + fsep);

    if ( texcoord.x < proscenium ) leftColor = float4( 0, 0, 0, 1 );
    if ( texcoord.x > 1.0f - proscenium ) rightColor = float4( 0, 0, 0, 1 );

    if ( texcoord.x < fsep.x || texcoord.x > 1.0 - fsep.x )
    {
        leftColor = rightColor = float4( 0, 0, 0, 1 );
    }

    output.r = dot(leftMask, rightColor);
    output.g = leftColor.g;
    output.b = leftColor.b;
    output.a = 1.0;

    return output;
}